@@ -51,7 +51,7 @@ class TestIro(unittest.TestCase):
         self.assertEqual(results['iroC'], '33-4%')
         self.assertEqual(results['iroD'], '12')
         self.assertEqual(results['iroN'], '15')
-        self.assertEqual(results['Salmochelin'], 'iro 4')
+        self.assertEqual(results['Salmochelin'], 'iro 4 (truncated)')
         self.assertEqual(results['SmST'], '33')
 
     def test_iro_inexact(self):
@@ -64,7 +64,7 @@ class TestIro(unittest.TestCase):
         self.assertEqual(results['iroC'], '33*-4%')
         self.assertEqual(results['iroD'], '12')
         self.assertEqual(results['iroN'], '15*')
-        self.assertEqual(results['Salmochelin'], 'iro 4')
+        self.assertEqual(results['Salmochelin'], 'iro 4 (truncated)')
         self.assertEqual(results['SmST'], '33-2LV')
 
     def test_iro_novel(self):
